JozzEvent class abstract
Abstract base class for all domain events.
This acts as a marker interface for domain events in the application. Extend this class to create custom domain events that can be published through the JozzBusService.
Constructors
- JozzEvent()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited